@@ -749,6 +749,12 @@ unsigned char *extract_ole(f_state *s, u_int64_t c_offset, unsigned char *founda
 		}
 
 	blknum = htoi((unsigned char *) &h->root_start_block, FOREMOST_LITTLE_ENDIAN);
+
+	if(blknum < 0)
+	{
+		return buf + 10;
+	}
+
 	highblock = htoi((unsigned char *) &h->dir_flag, FOREMOST_LITTLE_ENDIAN);
 #ifdef DEBUG
 	printf("getting dir block\n");
@@ -760,7 +766,7 @@ unsigned char *extract_ole(f_state *s, u_int64_t c_offset, unsigned char *founda
 #ifdef DEBUG
 	printf("done getting dir block\n");
 #endif
-	validblk = (blknum + 1) * OUR_BLK_SIZE;
+	validblk = (blknum + 1) * OUR_BLK_SIZE;	
 	while (blknum != END_OF_CHAIN)
 	{
 #ifdef DEBUG
@@ -771,7 +777,7 @@ unsigned char *extract_ole(f_state *s, u_int64_t c_offset, unsigned char *founda
 
 		/**PROBLEMA**/
 #ifdef DEBUG
-		printf("***blknum:=%d FATblk:=%d\n", blknum, FATblk);
+		printf("***blknum:=%d FATblk:=%d ourblksize=%d\n", blknum, FATblk,OUR_BLK_SIZE);
 #endif
 		oldblk = blknum;
 		htoi_c = (unsigned char *) &FAT[blknum / (OUR_BLK_SIZE / sizeof(int))];
@@ -1612,7 +1618,7 @@ unsigned char *extract_mpg(f_state *s, u_int64_t c_offset, unsigned char *founda
  *Function: extract_png
  *Description: Given that we have a PNG header parse the given buffer to determine
  *	where the file ends.
- *Return: A pointer to where the EOF of the JPEG is in the current buffer
+ *Return: A pointer to where the EOF of the PNG is in the current buffer
  **********************************************************************************/
 unsigned char *extract_png(f_state *s, u_int64_t c_offset, unsigned char *foundat, u_int64_t buflen,
 						   s_spec *needle, u_int64_t f_offset)
@@ -1712,7 +1718,7 @@ unsigned char *extract_jpeg(f_state *s, u_int64_t c_offset, unsigned char *found
 	unsigned char	*currentpos = NULL;
 
 	unsigned char	*extractbuf = NULL;
-	signed short	headersize = 0;
+	unsigned short	headersize = 0;
 	int				bytes_to_search = 0;
 	int				hasTable = FALSE;
 	int				hasHuffman = FALSE;
@@ -1751,13 +1757,6 @@ unsigned char *extract_jpeg(f_state *s, u_int64_t c_offset, unsigned char *found
 #ifdef DEBUG
 		printf("Headersize:=%d buflen:=%lld\n", headersize, buflen);
 #endif
-		if (headersize < 0)
-		{
-#ifdef DEBUG
-			printf("Negative header size\n");
-#endif
-			return buf + needle->header_len;;
-		}
 
 		if (headersize > buflen)
 			{
